# 更新日志
## [1.3.3] - 2026-1-25
### 新增
- 增加报文记录功能

## [1.3.0] - 2025-11-9
### 新增
- 增加0-9级密码设置
- 写参变量, 密码校验
- 读事件记录
### 修复
- 修复参变量读取时区只能读取到最后一项的Bug

## [1.2.0] - 2025-11-4
### 新增
- 超时时间范围内能够接收和处理分片数据
- 增加从站异常帧返回

## [1.1.1] - 2025-11-3
### 新增
- 补全参变量类型, 支持时区表和时段表数据
### 修复
- 需量设置bug修复，可以设置最大需量发生时间
- 修复数据域编解码加减0x33，数据溢出问题

## [1.1.0] - 2025-11-2
### 新增
- 增加参变量
### 修复
- 统一客户端和服务端接口命名

## [1.0.3] - 2025-11-1
### 新增
- 开放日志初始化设置接口
### 修复
- 客户端修复连接未重用Bug
- 读取通讯地址Bug修复

## [1.0.2] - 2025-10-27
### 修复
- 修复串口模式无法发送和接收数据Bug

## [1.0.0] - 2025-9-30
- 初始版本发布
